# delimit ;
 set more 1 ;
log using C:\HRS\SSA3\STATA\penacc.log, replace ;
drop _all;

use C:\HRS\SSA3\STATA\restrict3; 
* basic selection critieria;

*drop if age<51;
*drop if age>55;
drop if wave~=1;
drop if SScov==1 & SSYears>10;
drop if ((CalcpenCurr>1000000 & CalcpenCurr~=.)|(CalcpenLast>1000000 & CalcpenLast~=.)|(CalcpenPrev>1000000 & CalcpenPrev~=.)) & (SScov~=5|Govt~=5);

************************************************************************************;
* recode pensions here *************************************************************;
************************************************************************************;
* self reports first                                                                ;
* assume: ;
* 1) That the individual has a plan if he self-reports a plan;
* 2) The individual does not have a plan if his self-report is missing;

* first, however, deal with the fact that past pension plans are not reported in the basic data; 
replace penDBlast=penDBlast[_n-1] if penDBlast==. & HHID==HHID[_n-1] & PN==PN[_n-1];
replace penDClast=penDClast[_n-1] if penDClast==. & HHID==HHID[_n-1] & PN==PN[_n-1];
replace penDBprev=penDBprev[_n-1] if penDBprev==. & HHID==HHID[_n-1] & PN==PN[_n-1];
replace penDCprev=penDCprev[_n-1] if penDCprev==. & HHID==HHID[_n-1] & PN==PN[_n-1];

* next, assume the individual does not have a plan if his self-report is missing;
replace penDCcurr=0 if penDCcurr==.;
replace penDBcurr=0 if penDBcurr==.;
replace penDClast=0 if penDClast==.;
replace penDBlast=0 if penDBlast==.;
replace penDCprev=0 if penDCprev==.;
replace penDBprev=0 if penDBprev==.;

* now calculator values;
gen CalcDBCurr=CalcpenCurr-CalcDCCurr; * DB pension wealth;
gen CalcDBLast=CalcpenLast-CalcDCLast; * DB pension wealth;
gen CalcDBPrev=CalcpenPrev-CalcDCPrev; * DB pension wealth;

* now generate one's "true" pension type--overwrite the self-reports if the calculator says differently;
gen penDBcurrT=penDBcurr;
gen penDCcurrT=penDCcurr;
replace penDBcurrT=1 if (CalcDBCurr>0 & CalcDBCurr~=.)|CalcpenCurr==0; * CalcpenCurr==0 <==> assume this means the individual is not yet vested; 
replace penDBcurrT=0 if (CalcDBCurr==0)  & (CalcpenCurr~=. & CalcpenCurr>0); 
replace penDCcurrT=1 if (CalcDCCurr>0 & CalcDCCurr~=.);  
replace penDCcurrT=0 if (CalcDCCurr==0); 

gen penDBlastT=penDBlast;
gen penDClastT=penDClast;
replace penDBlastT=1 if (CalcDBLast>0 & CalcDBLast~=.)|CalcpenLast==0; * CalcpenLast==0 <==> assume this means the individual is not yet vested; 
replace penDBlastT=0 if (CalcDBLast==0)  & (CalcpenLast~=. & CalcpenLast>0); 
replace penDClastT=1 if (CalcDCLast>0 & CalcDCLast~=.);  
replace penDClastT=0 if (CalcDCLast==0); 

gen penDBprevT=penDBprev;
gen penDCprevT=penDCprev;
replace penDBprevT=1 if (CalcDBPrev>0 & CalcDBPrev~=.)|CalcpenPrev==0; * CalcpenPrev==0 <==> assume this means the individual is not yet vested; 
replace penDBprevT=0 if (CalcDBPrev==0)  & (CalcpenPrev~=. & CalcpenPrev>0); 
replace penDCprevT=1 if (CalcDCPrev>0 & CalcDCPrev~=.);  
replace penDCprevT=0 if (CalcDCPrev==0); 

*tab tenure if CalcpenCurr==0; * tenure is much lower for this group than for everyone--confirms hypothesis that these;
* people have DB plans, but are not yet vested;
*sum CalcpenCurr if CalcpenCurr==0;

* probabilities from the self-reports;
sum penD*;

* cross tab of self reports and inferred "truth";
tab penDBcurr penDBcurrT ;
tab penDCcurr penDCcurrT;

tab penDBlast penDBlastT ;
tab penDClast penDClastT;

tab penDBprev penDBprevT ;
tab penDCprev penDCprevT;

*************************************************************************;
* do you have a pension 						 ;
*************************************************************************;
gen pencurr=max(penDCcurr, penDBcurr);
gen penlast=max(penDClast, penDBlast);
gen penprev=max(penDCprev, penDBprev);


* generate insurance dummies, for different types of insurance;
* ommitted category, instype=1<==>none;
gen inseprhi=0;
replace inseprhi=1 if instype==2;
gen instied=0;
replace instied=1 if instype==3;

********************************************************;
**********calculate basic statistics********************;
sum lfpr ins* pen*;
sum Calc* pen* if pencurr==1;




*************now calculate accrual***********************;

set seed 53;
gen r=0.04; * real interest rate;
gen inf=0.02; * inflation rate;



*gen CalcDBLast=CalcpenLast-CalcDCLast; * DB pension wealth;
*gen CalcDBPrev=CalcpenPrev-CalcDCPrev; * DB pension wealth;

rename CalcpenCurr CalcpenCurr92;
rename CalcDCCurr CalcDCCurr92;

rename WageCurr WageCurr92;

gen retyear=.;
save C:\HRS\SSA3\STATA\penacc, replace;
clear;


local i = 93;
while `i' <= 110 {;
use C:\HRS\SSA3\STATA\penacc, replace;
local ilag = `i' - 1;
keep age CalcpenCurr`i' CalcpenCurr`ilag' ins* HHID PN lfpr retyear r inf earn pen*curr* WageCurr*;

* now calculator values;
*gen CalcDBCurr93=CalcpenCurr93-CalcDCCurr93; * DB pension wealth;
*gen CalcDBCurr94=CalcpenCurr94-CalcDCCurr94; * DB pension wealth;

replace retyear=`i';
gen pacc=CalcpenCurr`i' - ((1+r)*(1+inf)*CalcpenCurr`ilag');

rename CalcpenCurr`i'  CalcpenCurr;
rename CalcpenCurr`ilag'  CalcpenCurrlag;
rename WageCurr`i' WageCurr;


*********** age variables ***********************;
gen agetemp=age+(`ilag'-92);
replace age=agetemp;
drop agetemp;

gen age1=age;
gen age2=age1*age1;
gen age3=age2*age1;
gen age4=age3*age1;
gen age5=age4*age1;
gen age6=age5*age1;
gen age7=age6*age1;
gen age8=age7*age1;
gen age9=age8*age1;
gen age10=age9*age1;
gen age11=age10*age1;
gen age12=age11*age1;
gen age13=age12*age1;
gen age14=age13*age1;
gen age15=age14*age1;
gen age16=age15*age1;
gen age17=age16*age1;
gen age18=age17*age1;
gen age19=age18*age1;
gen age20=age19*age1;

gen age60=0; replace age60=1 if age>59;
gen age61=0; replace age61=1 if age>60;
gen age62=0; replace age62=1 if age>61;
gen age63=0; replace age63=1 if age>62;
gen age64=0; replace age64=1 if age>63;
gen age65=0; replace age65=1 if age>64;

gen agetied=0; replace agetied=age if instied==1;
gen ageeprhi=0; replace ageeprhi=age if inseprhi==1;

gen tied62=0; replace tied62=age62 if instied==1;
gen eprhi62=0; replace eprhi62=age62 if inseprhi==1;

gen tied65=0; replace tied65=age65 if instied==1;
gen eprhi65=0; replace eprhi65=age65 if inseprhi==1;

gen age2tied=0; replace age2tied=age2 if instied==1;
gen age2eprhi=0; replace age2eprhi=age2 if inseprhi==1;
gen age3tied=0; replace age3tied=age3 if instied==1;
gen age3eprhi=0; replace age3eprhi=age3 if inseprhi==1;

save C:\HRS\SSA3\STATA\penacc`i', replace;
local i =  `i' + 1;
};

clear;
use C:\HRS\SSA3\STATA\penacc93;
append using C:\HRS\SSA3\STATA\penacc94;
append using C:\HRS\SSA3\STATA\penacc95;
append using C:\HRS\SSA3\STATA\penacc96;
append using C:\HRS\SSA3\STATA\penacc97;
append using C:\HRS\SSA3\STATA\penacc98;
append using C:\HRS\SSA3\STATA\penacc99;
append using C:\HRS\SSA3\STATA\penacc100;
append using C:\HRS\SSA3\STATA\penacc101;
append using C:\HRS\SSA3\STATA\penacc102;
append using C:\HRS\SSA3\STATA\penacc103;
append using C:\HRS\SSA3\STATA\penacc104;
append using C:\HRS\SSA3\STATA\penacc105;
append using C:\HRS\SSA3\STATA\penacc106;
append using C:\HRS\SSA3\STATA\penacc107;
append using C:\HRS\SSA3\STATA\penacc108;
append using C:\HRS\SSA3\STATA\penacc109;
append using C:\HRS\SSA3\STATA\penacc110;


save C:\HRS\SSA3\STATA\penacc1, replace;



save C:\HRS\SSA3\STATA\penacc1, replace;
log close ;
program drop _all ;
*drop _all ;

