# delimit ;
 set more 1 ;
capture log close;
log using C:\HRS\SSA3\STATA\restrict4.log, replace ;
drop _all;
set mem 500m;

use C:\HRS\SSA3\STATA\restrict3; 
* basic selection critieria;
set seed 53;

sum HHID;
gen omHHID=1-HHID;

*drop if age<51;
*drop if age>55;
gen age2=age*age;
gen age3=age2*age;
drop if wave~=1;
drop if SScov==1 & SSYears>10;
drop if ((CalcpenCurr>1000000 & CalcpenCurr~=.)|(CalcpenLast>1000000 & CalcpenLast~=.)|(CalcpenPrev>1000000 & CalcpenPrev~=.)) & (SScov~=5|Govt~=5);
sum HHID;




************************************************************************************;
* recode pensions here *************************************************************;
************************************************************************************;
* self reports first                                                                ;
* assume: ;
* 1) That the individual has a plan if he self-reports a plan;
* 2) The individual does not have a plan if his self-report is missing;

* first, however, deal with the fact that past pension plans are not reported in the basic data; 
replace penDBlast=penDBlast[_n-1] if penDBlast==. & HHID==HHID[_n-1] & PN==PN[_n-1];
replace penDClast=penDClast[_n-1] if penDClast==. & HHID==HHID[_n-1] & PN==PN[_n-1];
replace penDBprev=penDBprev[_n-1] if penDBprev==. & HHID==HHID[_n-1] & PN==PN[_n-1];
replace penDCprev=penDCprev[_n-1] if penDCprev==. & HHID==HHID[_n-1] & PN==PN[_n-1];

* next, assume the individual does not have a plan if his self-report is missing;
replace penDCcurr=0 if penDCcurr==.;
replace penDBcurr=0 if penDBcurr==.;
replace penDClast=0 if penDClast==.;
replace penDBlast=0 if penDBlast==.;
replace penDCprev=0 if penDCprev==.;
replace penDBprev=0 if penDBprev==.;

* now calculator values;
gen CalcDBCurr=CalcpenCurr-CalcDCCurr; * DB pension wealth;
gen CalcDBLast=CalcpenLast-CalcDCLast; * DB pension wealth;
gen CalcDBPrev=CalcpenPrev-CalcDCPrev; * DB pension wealth;

* now generate one's "true" pension type--overwrite the self-reports if the calculator says differently;
gen penDBcurrT=penDBcurr;
gen penDCcurrT=penDCcurr;
replace penDBcurrT=1 if (CalcDBCurr>0 & CalcDBCurr~=.)|CalcpenCurr==0; * CalcpenCurr==0 <==> assume this means the individual is not yet vested; 
replace penDBcurrT=0 if (CalcDBCurr==0)  & (CalcpenCurr~=. & CalcpenCurr>0); 
replace penDCcurrT=1 if (CalcDCCurr>0 & CalcDCCurr~=.);  
replace penDCcurrT=0 if (CalcDCCurr==0); 

gen penDBlastT=penDBlast;
gen penDClastT=penDClast;
replace penDBlastT=1 if (CalcDBLast>0 & CalcDBLast~=.)|CalcpenLast==0; * CalcpenLast==0 <==> assume this means the individual is not yet vested; 
replace penDBlastT=0 if (CalcDBLast==0)  & (CalcpenLast~=. & CalcpenLast>0); 
replace penDClastT=1 if (CalcDCLast>0 & CalcDCLast~=.);  
replace penDClastT=0 if (CalcDCLast==0); 

gen penDBprevT=penDBprev;
gen penDCprevT=penDCprev;
replace penDBprevT=1 if (CalcDBPrev>0 & CalcDBPrev~=.)|CalcpenPrev==0; * CalcpenPrev==0 <==> assume this means the individual is not yet vested; 
replace penDBprevT=0 if (CalcDBPrev==0)  & (CalcpenPrev~=. & CalcpenPrev>0); 
replace penDCprevT=1 if (CalcDCPrev>0 & CalcDCPrev~=.);  
replace penDCprevT=0 if (CalcDCPrev==0); 

*tab tenure if CalcpenCurr==0; * tenure is much lower for this group than for everyone--confirms hypothesis that these;
* people have DB plans, but are not yet vested;
*sum CalcpenCurr if CalcpenCurr==0;

* probabilities from the self-reports;
sum penD*;

* cross tab of self reports and inferred "truth";
tab penDBcurr penDBcurrT ;
tab penDCcurr penDCcurrT;

tab penDBlast penDBlastT ;
tab penDClast penDClastT;

tab penDBprev penDBprevT ;
tab penDCprev penDCprevT;


*************************************************************************;
* do you have a pension 						 ;
*************************************************************************;
gen pencurr=max(penDCcurr, penDBcurr);
gen penlast=max(penDClast, penDBlast);
gen penprev=max(penDCprev, penDBprev);

* now generate a variable = 1 if pension calculator data are missing;
gen pencurrmiss=0;
replace pencurrmiss=1 if CalcpenCurr==. & pencurr==1;
gen penlastmiss=0;
replace penlastmiss=1 if CalcpenLast==. & penlast==1;
gen penprevmiss=0;
replace penprevmiss=1 if CalcpenPrev==. & penprev==1;


***************************************************************************;
* some descriptive statistics reported in the paper ***********************;
***************************************************************************;
gen ager=0;
replace ager=1 if birthyr>1930 & birthyr<1936;
replace ager=2 if birthyr>1935 & birthyr<1942;

sort ager;
by ager: sum pencurr penlast penprev age;

by ager: sum pencurrmiss if pencurr==1;
by ager: sum penlastmiss if penlast==1;
by ager: sum penprevmiss if penprev==1;



* if pension data from the pension calculator are missing, here is what we do;
* we use self-reported DC wealth					     ;
* ie, we set DC wealth equal to self-reported DC wealth, if missing	     ;
* and we impute DB wealth if missing 					     ;

*****************************************************************************;
* use self reported DC wealth, unless it appears to be missing               ;
* if it is missing, use company reported DC wealth                           ;
* does this make sense for previous plans?  What is someone "cashed out" of a;
* previous plan?  would the firm response still have the full value of that  ;
* wealth?                                                                    ;
*****************************************************************************;

gen trueDBcurr=CalcDBCurr;
gen trueDCcurr=penwDCcurr;
replace trueDCcurr=CalcDCCurr if (trueDCcurr==.|(trueDCcurr==0 & CalcDCCurr~=.)); 
replace trueDBcurr=0 if trueDBcurr==. & (pencurr==0|penDBcurr==0); * 0 if you did not have a pension; 
replace trueDCcurr=0 if trueDCcurr==. & (pencurr==0|penDCcurr==0); * 0 if you did not have a pension; 

gen trueDBlast=CalcDBLast;
gen trueDClast=penwDClast ;
replace trueDClast=CalcDCLast if (trueDClast==.|(trueDClast==0 & CalcDCLast~=.)); 
replace trueDBlast=0 if trueDBlast==. & (penlast==0|penDBlast==0); * 0 if you did not have a pension; 
replace trueDClast=0 if trueDClast==. & (penlast==0|penDClast==0); * 0 if you did not have a pension; 

gen trueDBprev=CalcDBPrev;
gen trueDCprev=penwDCprev;
replace trueDCprev=CalcDCPrev if (trueDCprev==.|(trueDCprev==0 & CalcDCPrev~=.)); 
replace trueDBprev=0 if trueDBprev==. & (penprev==0|penDBprev==0); * 0 if you did not have a pension; 
replace trueDCprev=0 if trueDCprev==. & (penprev==0|penDCprev==0); * 0 if you did not have a pension; 

* figure out pension wealth, by pension type;
sort penDBcurrT;
by penDBcurrT: sum penDBcurrT true*curr;
sort penDBlastT;
by penDBlastT: sum penDBlastT true*last;
sort penDBprevT;
by penDBprevT: sum penDBprevT true*prev;

* now we need to impute DB pension wealth for those with no restricted pension information;
* for those who have a DC plan, we used self-reported DC wealth                           ;


* generate insurance dummies, for different types of insurance;
* ommitted category, instype=1<==>none;
gen inseprhi=0;
replace inseprhi=1 if instype==2;
gen instied=0;
replace instied=1 if instype==3;

replace ind=0 if ind==.;
replace occ=0 if occ==.;
tab ind, gen(i);
tab occ, gen(o);
sum i* o*;

gen lwage=ln(wage);
gen lten=ln(tenure);
gen lhours=ln(hours);
gen e=lhours+lwage;
gen wageten=wage*tenure;


*generate a variable for total tenure, all jobs;
gen tottenure=tenure;
replace tottenure=(tottenure + tenurelast) if tenurelast~=.;
replace tottenure=(tottenure + tenureprev) if tenureprev~=.; 
gen theearn=earn;
replace theearn=WageCurr if theearn==.;
replace theearn=earnlast if theearn==.;
replace theearn=WageLast if theearn==.;
replace theearn=earnprev if theearn==.;
replace theearn=WagePrev if theearn==.;
gen earnten=theearn*tottenure;

gen totwork=0; * work at all jobs;
replace totwork=totwork+tenure if tenure ~=.;
replace totwork=totwork+tenurelast if tenurelast~=.;
replace totwork=totwork+tenureprev if tenureprev~=.;



****************************************************************************************;
* DB IMPUTATION PROCEDURE HERE								;
****************************************************************************************;
***********CURRENT MAIN JOB ************************************************************;
gen fac=wage*hours*tenure;  * everyone has these three variables if CalcDBCurr is not missing and matchcrit=1;
gen plangen=CalcDBCurr/fac; * plan generosity;

* basic match criteria;
gen matchcrit=1;
replace matchcrit=0 if penDBcurrT~=1; *lots of people have a plangen(=0), who have DC pensions;
replace matchcrit=0 if (tenure<3|wage<3|hours<300);

reg plangen wage lwage lmedcost lten wageten assets healw inseprhi instied penDBcurr penDCcurr tenure  vla age age2 age3 i1-i13 o1-o17 if  matchcrit==1;
predict plangenp;

* for those with missing obs;
gen pmiss=0;
replace pmiss=1 if plangenp==.;

reg plangen inseprhi instied age age2 age3 if  matchcrit==1;

predict plangenpsm;
replace plangenp=plangenpsm if pmiss==1;

gen residsmt = (plangen-plangenp);
sort residsmt;



***********************************************************
* deciles are based on all xB who meet the match criteria
***********************************************************;


  local i = 10;
  while `i' < 100 {;
    egen plangenp`i' = pctile(plangenp) if matchcrit == 1, p(`i');
	sum plangenp`i';
	sort plangenp`i';
	replace plangenp`i'=plangenp`i'[_n-1] if plangenp`i'==.;
    local i = `i' + 10;
  };


***********************************************************
*  Two groups are found within our decile, the "Donor" group
*  (who have a value for plan gen and matchcrit == 1) and
*  a recipient group (who are in the right decile).
*  The donor group's size is stored in "max" while the 
*  recipient group's size is stored in "max2".  Each memeber
*  of the decile has sortflag = 0 while each member of the 
*  decile that is a donor has sortflag2 = 0.
*  The loop then assigns everyone in the decile a random draw
*  from the donor group.
***********************************************************;

gen residmatch = .;

local i = 1;
qui sum plangenp if plangenp <= plangenp10 & plangen ~= . & matchcrit == 1;
local max = r(N); *Donor group;
gen sortflag2 = 1;
replace sortflag2 = 0 if plangenp <= plangenp10 & plangen ~= . & matchcrit == 1; *Donor group;



gen sortflag = 1;
replace sortflag = 0 if plangenp <= plangenp10 & plangenp~=.; *Full Decile;
qui sum if plangenp <= plangenp10 & plangenp~=.;
local max2 = r(N); *Full Decile;
sort sortflag sortflag2 HHIDPN;

display `max' ;
display `max2';

while `i' <= `max2' {;
  local i2 = ceil(uniform()*`max');
  qui replace residmatch = residsmt[`i2'] in `i';
  local i = `i' + 1;
};



local ranger = 20;
while `ranger' <= 90 {;
  local mranger = `ranger' - 10;
  local i = 1;
  qui sum plangenp if plangenp <= plangenp`ranger' & plangenp > plangenp`mranger' & plangen ~= . & matchcrit == 1; *Donor Group;
  local max = r(N);
  qui sum plangenp if plangenp <= plangenp`ranger' & plangenp > plangenp`mranger'; *Full Decile;
  local max2 = r(N);
  replace sortflag2 = 1;
  replace sortflag2 = 0 if plangenp <= plangenp`ranger' & plangenp > plangenp`mranger' & plangen ~= . & matchcrit == 1; *Donor Group;
  replace sortflag = 1;
  replace sortflag = 0 if plangenp <= plangenp`ranger' & plangenp > plangenp`mranger'; *Full Decile;
  sort sortflag sortflag2 HHIDPN;

  while `i' <= `max2' {;

    local i2 = ceil(uniform()*`max');
    qui replace residmatch = residsmt[`i2'] in `i';
  local i = `i' + 1;
  };
local ranger = `ranger' + 10;
};

local i = 1;
qui sum plangenp if plangenp > plangenp90 & plangen ~= . & matchcrit == 1; *Donor Group;
local max = r(N);
qui sum plangenp if plangenp > plangenp90; *Full Decile;
local max2 = r(N);

replace sortflag = 1;
replace sortflag = 0 if plangenp > plangenp90; *Full Decile;
replace sortflag2 = 1;
replace sortflag2 = 0 if plangenp > plangenp90 & plangen ~= . & matchcrit == 1; *Donor Group;
sort sortflag sortflag2 HHIDPN;
while `i' <= `max2' {;
  local i2 = ceil(uniform()*`max');
  qui replace residmatch =  residsmt[`i2'] in `i';
  local i = `i' + 1;
};

*************************************************
*  Finally, values are imputed.
*************************************************;

gen plangenpp=plangenp+residmatch;
sum plangenpp plangen;
replace plangen=plangenpp if plangen==.;

drop matchcrit  sortflag* resid* pmiss;

sum plangen;
replace plangen=0 if penDBcurrT==0;
replace trueDBcurr=plangen*wage*hours*tenure if trueDBcurr==.;
replace trueDBcurr=0 if trueDBcurr==.|trueDBcurr<0; * only two missings;



***********LAST JOB ************************************************************;
sort HHID PN wave;
replace tenurelast=tenurelast[_n-1] if HHID==HHID[_n-1] & PN==PN[_n-1];
gen faclast=tenurelast*earnlast;

gen plangenlast=CalcDBLast/faclast; * plan generosity;

* basic match criteria;
gen matchcrit=1;
replace matchcrit=0 if penDBlastT~=1; *lots of people have a plangen(=0), who have DC pensions;
replace matchcrit=0 if (tenurelast<3|earnlast<2000);


reg plangenlast lmedcost assets healw inseprhi penDBcurr penDCcurr tenurelast  vla age age2 age3 if  matchcrit==1;
predict plangenlastp;

* for those with missing obs;
gen plastmiss=0;
replace plastmiss=1 if plangenlastp==.;

reg plangenlast inseprhi age age2 age3 if  matchcrit==1;

predict plangenlastpsm;
replace plangenlastp=plangenlastpsm if plastmiss==1;


gen residsmt=(plangenlast-plangenlastp);

****** get percentiles of predicted distribution;

  local i = 10;
  while `i' < 100 {;
    egen plangenlastp`i' = pctile(plangenlastp) if matchcrit == 1, p(`i') ;
	sum plangenlastp`i';
	sort plangenlastp`i';
	replace plangenlastp`i'=plangenlastp`i'[_n-1] if plangenlastp`i'==.;
    local i = `i' + 10;
  };


* now do the matching **************;

gen residmatch = .;

local i = 1;
qui sum plangenlastp if plangenlastp <= plangenlastp10 & plangenlast ~= . & matchcrit == 1;
local max = r(N);
qui sum plangenlastp if plangenlastp <= plangenlastp10;
local max2 = r(N);

gen sortflag = 1;
replace sortflag = 0 if plangenlastp <= plangenlastp10;
gen sortflag2 = 1;
replace sortflag2 = 0 if plangenlastp <= plangenlastp10 & plangenlast ~= . & matchcrit == 1;

sort sortflag sortflag2 HHIDPN;

while `i' <= `max2' {;
  local i2 = ceil(uniform()*`max');
  qui replace residmatch = residsmt[`i2'] in `i';
  local i = `i' + 1;
};
sum plangenlastp if plangenlastp < plangenlastp10;
sum residsmt if plangenlastp < plangenlastp10;
sum residmatch;

local ranger = 20;
while `ranger' <= 90 {;
  local mranger = `ranger' - 10;
  local i = 1;
  qui sum plangenlastp if plangenlastp <= plangenlastp`ranger' & plangenlastp > plangenlastp`mranger' & plangenlast ~= . & matchcrit == 1;
  local max = r(N);
  qui sum plangenlastp if plangenlastp <= plangenlastp`ranger' & plangenlastp > plangenlastp`mranger';
  local max2 = r(N);
  replace sortflag = 1;
  replace sortflag = 0 if plangenlastp <= plangenlastp`ranger' & plangenlastp > plangenlastp`mranger';
  replace sortflag2 = 1;
  replace sortflag2 = 0 if plangenlastp <= plangenlastp`ranger' & plangenlastp > plangenlastp`mranger' & plangenlast ~= . & matchcrit == 1;
  sort sortflag sortflag2 HHIDPN;
  while `i' <= `max2' {;
    local i2 = ceil(uniform()*`max');
    qui replace residmatch = residsmt[`i2'] in `i';
  local i = `i' + 1;
  };
local ranger = `ranger' + 10;
};

local i = 1;
qui sum plangenlastp if plangenlastp > plangenlastp90 & plangenlast ~= . & matchcrit == 1;
local max = r(N);
qui sum plangenlastp if plangenlastp > plangenlastp90;
local max2 = r(N);
replace sortflag = 1;
replace sortflag = 0 if plangenlastp > plangenlastp90;
replace sortflag2 = 1;
replace sortflag2 = 0 if plangenlastp > plangenlastp90 & plangenlast ~= . & matchcrit == 1;

sort sortflag sortflag2 HHIDPN;
while `i' <= `max2' {;
  local i2 = ceil(uniform()*`max');
  qui replace residmatch =  residsmt[`i2'] in `i';
  local i = `i' + 1;
};


gen plangenlastpp=plangenlastp+residmatch;
sum plangenlastpp plangenlast;
replace plangenlast=plangenlastpp if plangenlast==.;

drop matchcrit  sortflag* resid*  plastmiss;

sum plangenlast;
replace plangenlast=0 if penDBlastT==0;
replace trueDBlast=plangenlast*earnlast*tenurelast if trueDBlast==.;

sum trueDBlast;

replace trueDBlast=0 if trueDBlast==.|trueDBlast<0; 

sum trueDBlast;


***********PREVIOUS JOB ************************************************************;
sort HHID PN wave;
replace tenureprev=tenureprev[_n-1] if HHID==HHID[_n-1] & PN==PN[_n-1];
gen facprev=tenureprev*earnprev;

gen pprev=CashFlowsPrev1/facprev;

gen plangenprev=CalcDBPrev/facprev; * plan generosity;


* basic match criteria;
gen matchcrit=1;
replace matchcrit=0 if penDBprevT~=1; *lots of people have a plangen(=0), who have DC pensions;
replace matchcrit=0 if (tenureprev<3|earnprev<2000);
replace matchcrit=0 if (plangenprev>2 & plangenprev~=.);
replace matchcrit=0 if (pprev>.03 & pprev~=.); * this is really ad hoc -- it says "dont use the observation if it seems too generous";

*XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX;

* reg plangenprev theearn  wage lwage lmedcost lten wageten assets healw inseprhi instied penDBcurr penDCcurr tottenure  vla age age2 age3  if  matchcrit==1;
reg plangenprev theearn  wage lwage lmedcost lten wageten assets healw inseprhi instied penDBcurr penDCcurr tottenure  vla age age2 age3 i1-i13 o1-o17 if  matchcrit==1;
predict plangenprevp;

* for those with missing obs;
gen pprevmiss=0;
replace pprevmiss=1 if plangenprevp==.;

reg plangenprev inseprhi age age2 age3 if  matchcrit==1;

predict plangenprevpsm;
replace plangenprevp=plangenprevpsm if pprevmiss==1;
sum plangenprevp;

gen residsmt=(plangenprev-plangenprevp);

* get pecentiles of predicted distribution;
 
  local i = 10;
  while `i' < 100 {;
    egen plangenprevp`i' = pctile(plangenprevp) if matchcrit == 1, p(`i');
	sum plangenprevp`i';
	sort plangenprevp`i';
	replace plangenprevp`i'=plangenprevp`i'[_n-1] if plangenprevp`i'==.;
    local i = `i' + 10;
  };

* match      ;

gen residmatch = .;

local i = 1;
qui sum plangenprevp if plangenprevp <= plangenprevp10 & plangenprev ~= . & matchcrit == 1;
local max = r(N);
qui sum plangenprevp if plangenprevp <= plangenprevp10;
local max2 = r(N);

gen sortflag = 1;
replace sortflag = 0 if plangenprevp <= plangenprevp10;
gen sortflag2 = 1;
replace sortflag2 = 0 if plangenprevp <= plangenprevp10 & plangenprev ~= . & matchcrit == 1;

sort sortflag sortflag2 HHIDPN;

while `i' <= `max2' {;
  local i2 = ceil(uniform()*`max');
  qui replace residmatch = residsmt[`i2'] in `i';
  local i = `i' + 1;
};
sum plangenprevp if plangenprevp < plangenprevp10;
sum residsmt if plangenprevp < plangenprevp10;
sum residmatch;

local ranger = 20;
while `ranger' <= 90 {;
  local mranger = `ranger' - 10;
  local i = 1;
  qui sum plangenprevp if plangenprevp <= plangenprevp`ranger' & plangenprevp > plangenprevp`mranger' & plangenprev ~= . & matchcrit == 1;
  local max = r(N);
  qui sum plangenprevp if plangenprevp <= plangenprevp`ranger' & plangenprevp > plangenprevp`mranger';
  local max2 = r(N);
  replace sortflag = 1;
  replace sortflag = 0 if plangenprevp <= plangenprevp`ranger' & plangenprevp > plangenprevp`mranger';
  replace sortflag2 = 1;
  replace sortflag2 = 0 if plangenprevp <= plangenprevp`ranger' & plangenprevp > plangenprevp`mranger' & plangenprev ~= . & matchcrit == 1;
  sort sortflag sortflag2  HHIDPN;
  while `i' <= `max2' {;
    local i2 = ceil(uniform()*`max');
    qui replace residmatch = residsmt[`i2'] in `i';
  local i = `i' + 1;
  };
local ranger = `ranger' + 10;
};

local i = 1;
qui sum plangenprevp if plangenprevp > plangenprevp90 & plangenprev ~= . & matchcrit == 1;
local max = r(N);
qui sum plangenprevp if plangenprevp > plangenprevp90;
local max2 = r(N);
replace sortflag = 1;
replace sortflag = 0 if plangenprevp > plangenprevp90;
replace sortflag2 = 1;
replace sortflag2 = 0 if plangenprevp > plangenprevp90 & plangenprev ~= . & matchcrit == 1;

sort sortflag sortflag2 HHIDPN;
while `i' <= `max2' {;
  local i2 = ceil(uniform()*`max');
  qui replace residmatch =  residsmt[`i2'] in `i';
  local i = `i' + 1;
};

gen plangenprevpp=plangenprevp+residmatch;
sum plangenprevpp plangenprev;
replace plangenprev=plangenprevpp if plangenprev==.;

drop matchcrit  sortflag* resid*  pprevmiss;

sum plangenprev;
replace plangenprev=0 if penDBprevT==0;
replace trueDBprev=plangenprev*earnprev*tenureprev if trueDBprev==.;

sum trueDBprev;

replace trueDBprev=0 if trueDBprev==.|trueDBprev<0; 

sum trueDBprev;

***********************************;
* indicators for data being missing;
***********************************;
gen AIMEmiss=0;
gen pensionmissCurr=0;
gen pensionmissLast=0;
gen pensionmissPrev=0;
replace AIMEmiss=1 if AIME==.;
replace pensionmissCurr=1 if CalcpenCurr==.;
replace pensionmissLast=1 if CalcpenLast==.;
replace pensionmissPrev=1 if CalcpenPrev==.;
* these variables were previously imputed;
replace wage=. if wagemiss==1;

sum *miss *medcost medcost;
replace lmedcost=. if medcostmiss==1;
*replace medcost=. if medcostmiss==1;
sum *miss *medcost medcost;


* gerate logs of some variables, deal with the fact that some of these are equal to 0;
gen AIMEguess=AIME;
replace AIMEguess=1000 if AIME<1000 & AIME~=.;
gen lAIME=ln(AIMEguess);

gen CalcpenguessCurr=CalcpenCurr;
replace CalcpenguessCurr=1000 if CalcpenCurr<1000 & CalcpenCurr~=.;
gen lpenCurr=ln(CalcpenguessCurr);


gen qrttotalguess=qrttotal;
replace qrttotalguess=10 if qrttotal<10 & qrttotal~=.;
gen ltotal=ln(qrttotal);
gen assguess=assets;
replace assguess=1000 if assets<1000 & assets~=.;
gen lass=ln(assguess);

* generate insurance dummies, for different types of insurance;
* ommitted category, instype=1<==>none;
*gen inseprhi=0;
*replace inseprhi=1 if instype==2;
*gen instied=0;
*replace instied=1 if instype==3;


*********************************************************************;
*                 wages first                                        ;
*gen lwage =ln(wage);
gen matchcrit = 1;
sum wage lwage;
reg lwage assets healw inseprhi instied lfpr penDBcurr penDCcurr AIME qrttotal age age2 age3;
/*
reg lwage lass healw instype lfpr AIME qrttotal;
reg lwage lass healw instype lfpr lAIME ltotal;
reg lwage assets healw instype lfpr AIME qrttotal lpen;
reg lwage assets healw instype lfpr ;
*/
predict lwagep;
/*
gen resid=(lwage-lwagep)*(lwage-lwagep);
egen var=mean(resid);
replace resid=sqrt(var);
*/
* for those with missing obs;
gen wmiss=0;
replace wmiss=1 if lwagep==.;
reg lwage assets healw inseprhi instied lfpr age age2 age3;
predict lwagepsm;
/*
gen residsm=(lwage-lwagepsm)*(lwage-lwagepsm);
egen varsm=mean(residsm);
replace residsm=sqrt(varsm);
replace resid=residsm if wmiss==1; 

*/

replace lwagep=lwagepsm if wmiss==1;


gen residsmt=(lwage-lwagep);


* generate deciles of the predicted values;
  local i = 10;
  while `i' < 100 {;
    egen lwagep`i' = pctile(lwagep) if matchcrit == 1, p(`i');
	sort lwagep`i';
	replace lwagep`i'=lwagep`i'[_n-1] if lwagep`i'==.;
    local i = `i' + 10;
  };


* do matching;

gen residmatch = .;

local i = 1;
qui sum lwagep if lwagep <= lwagep10 & lwage ~= . & matchcrit == 1;
local max = r(N);
qui sum lwagep if lwagep <= lwagep10;
local max2 = r(N);

gen sortflag = 1;
replace sortflag = 0 if lwagep <= lwagep10;
gen sortflag2 = 1;
replace sortflag2 = 0 if lwagep <= lwagep10 & lwage ~= . & matchcrit == 1;

sort sortflag sortflag2 HHIDPN;

while `i' <= `max2' {;
  local i2 = ceil(uniform()*`max');
  qui replace residmatch = residsmt[`i2'] in `i';
  local i = `i' + 1;
};
sum lwagep if lwagep < lwagep10;
sum residsmt if lwagep < lwagep10;
sum residmatch;

local ranger = 20;
while `ranger' <= 90 {;
  local mranger = `ranger' - 10;
  local i = 1;
  qui sum lwagep if lwagep <= lwagep`ranger' & lwagep > lwagep`mranger' & lwage ~= . & matchcrit == 1;
  local max = r(N);
  qui sum lwagep if lwagep <= lwagep`ranger' & lwagep > lwagep`mranger';
  local max2 = r(N);

  replace sortflag = 1;
  replace sortflag = 0 if lwagep <= lwagep`ranger' & lwagep > lwagep`mranger';
  replace sortflag2 = 1;
  replace sortflag2 = 0 if lwagep <= lwagep`ranger' & lwagep > lwagep`mranger' & lwage ~= . & matchcrit == 1;
  sort sortflag sortflag2 HHIDPN;
  while `i' <= `max2' {;
    local i2 = ceil(uniform()*`max');
    qui replace residmatch = residsmt[`i2'] in `i';
  local i = `i' + 1;
  };
local ranger = `ranger' + 10;
};

local i = 1;
qui sum lwagep if lwagep > lwagep90 & lwage ~= . & matchcrit == 1;
local max = r(N);
qui sum lwagep if lwagep > lwagep90;
local max2 = r(N);
replace sortflag = 1;
replace sortflag = 0 if lwagep > lwagep90;
replace sortflag2 = 1;
replace sortflag2 = 0 if lwagep > lwagep90 & lwage ~= . & matchcrit == 1;

sort sortflag sortflag2 HHIDPN;
while `i' <= `max2' {;
  local i2 = ceil(uniform()*`max');
  qui replace residmatch =  residsmt[`i2'] in `i';
  local i = `i' + 1;
};


replace lwage=. if wagemiss==1;
gen lwagepp=lwagep+residmatch;
sum lwagepp lwage;
replace lwage=lwagepp if lwage==.;
drop wage;
gen wage=exp(lwage);

sum residmatch lwage* wage;

drop matchcrit  sortflag* resid*  wmiss;

*********************************************************************;
*               medical expenses                                     ;
gen matchcrit = 1;

reg lmedcost assets healw inseprhi instied lfpr penDBcurr penDCcurr AIME qrttotal age age2 age3;
predict lmedcostp;

* for those with missing obs;
gen mmiss=0;
replace mmiss=1 if lmedcostp==.;
reg lmedcost  assets healw inseprhi instied lfpr age age2 age3;
predict lmedcostpsm;

replace lmedcostp=lmedcostpsm if mmiss==1;

gen residsmt=(lmedcost-lmedcostp);

  local i = 10;
  while `i' < 100 {;
    egen lmedcostp`i' = pctile(lmedcostp) if matchcrit == 1, p(`i');
	sort lmedcostp`i';
	replace lmedcostp`i'=lmedcostp`i'[_n-1] if lmedcostp`i'==.;
    local i = `i' + 10;
  };


* generate N(0,1) r.v.s;
gen residmatch = .;

local i = 1;
qui sum lmedcostp if lmedcostp <= lmedcostp10 & lmedcost ~= . & matchcrit == 1;
local max = r(N);

qui sum lmedcostp if lmedcostp <= lmedcostp10;
local max2 = r(N);

gen sortflag = 1;
replace sortflag = 0 if lmedcostp <= lmedcostp10;
gen sortflag2 = 1;
replace sortflag2 = 0 if lmedcostp <= lmedcostp10 & lmedcost ~= . & matchcrit == 1;

sort sortflag sortflag2 HHIDPN;

while `i' <= `max2' {;
  local i2 = ceil(uniform()*`max');
  qui replace residmatch = residsmt[`i2'] in `i';
  local i = `i' + 1;
};
sum lmedcostp if lmedcostp < lmedcostp10;
sum residsmt if lmedcostp < lmedcostp10;
sum residmatch;

local ranger = 20;
while `ranger' <= 90 {;
  local mranger = `ranger' - 10;
  local i = 1;
  qui sum lmedcostp if lmedcostp <= lmedcostp`ranger' & lmedcostp > lmedcostp`mranger' & lmedcost ~= . & matchcrit == 1;
  local max = r(N);
  qui sum lmedcostp if lmedcostp <= lmedcostp`ranger' & lmedcostp > lmedcostp`mranger';
  local max2 = r(N);

  replace sortflag = 1;
  replace sortflag = 0 if lmedcostp <= lmedcostp`ranger' & lmedcostp > lmedcostp`mranger';
  replace sortflag2 = 1;
  replace sortflag2 = 0 if lmedcostp <= lmedcostp`ranger' & lmedcostp > lmedcostp`mranger' & lmedcost ~= . & matchcrit == 1;

  sort sortflag sortflag2 HHIDPN;
  while `i' <= `max2' {;
    local i2 = ceil(uniform()*`max');
    qui replace residmatch = residsmt[`i2'] in `i';
  local i = `i' + 1;
  };
local ranger = `ranger' + 10;
};

local i = 1;
qui sum lmedcostp if lmedcostp > lmedcostp90 & lmedcost ~= . & matchcrit == 1;
local max = r(N);
qui sum lmedcostp if lmedcostp > lmedcostp90;
local max2 = r(N);
replace sortflag = 1;
replace sortflag = 0 if lmedcostp > lmedcostp90;
replace sortflag2 = 1;
replace sortflag2 = 0 if lmedcostp > lmedcostp90 & lmedcost ~= . & matchcrit == 1;

sort sortflag sortflag2 HHIDPN;
while `i' <= `max2' {;
  local i2 = ceil(uniform()*`max');
  qui replace residmatch =  residsmt[`i2'] in `i';
  local i = `i' + 1;
};

gen lmedpp=lmedcostp+residmatch;
sum lmedpp lmedcost;
replace lmedcost=lmedpp if lmedcost==.;
gen medcost=exp(lmedcost);

drop matchcrit  sortflag* resid*  mmiss;

*********************************************************************;
*               AIME                                                 ;
*********************************************************************;

gen matchcrit = 1;
reg AIME assets healw inseprhi instied lfpr penDBcurr penDCcurr tottenure theearn earnten age age2 age3;
predict AIMEp;
* for those with missing obs;
gen Amiss=0;
replace Amiss=1 if AIMEp==.;
reg AIME assets healw inseprhi instied lfpr age age2 age3;
predict AIMEpsm;

replace AIMEp=AIMEpsm if Amiss==1;

gen residsmt=(AIME-AIMEp);

  local i = 10;
  while `i' < 100 {;
    egen AIMEp`i' = pctile(AIMEp) if matchcrit == 1, p(`i');
	sort AIMEp`i';
	replace AIMEp`i'=AIMEp`i'[_n-1] if AIMEp`i'==.;

    local i = `i' + 10;
  };


gen residmatch = .;

local i = 1;
qui sum AIMEp if AIMEp <= AIMEp10 & AIME ~= . & matchcrit == 1;
local max = r(N);

qui sum AIMEp if AIMEp <= AIMEp10;
local max2 = r(N);

gen sortflag = 1;
replace sortflag = 0 if AIMEp <= AIMEp10;
gen sortflag2 = 1;
replace sortflag2 = 0 if AIMEp <= AIMEp10 & AIME ~= . & matchcrit == 1;

sort sortflag sortflag2 HHIDPN;

while `i' <= `max2' {;
  local i2 = ceil(uniform()*`max');
  qui replace residmatch = residsmt[`i2'] in `i';
  local i = `i' + 1;
};
sum AIMEp if AIMEp < AIMEp10;
sum residsmt if AIMEp < AIMEp10;
sum residmatch;

local ranger = 20;
while `ranger' <= 90 {;
  local mranger = `ranger' - 10;
  local i = 1;
  qui sum AIMEp if AIMEp <= AIMEp`ranger' & AIMEp > AIMEp`mranger' & AIME ~= . & matchcrit == 1;
  local max = r(N);
  qui sum AIMEp if AIMEp <= AIMEp`ranger' & AIMEp > AIMEp`mranger';
  local max2 = r(N);
  replace sortflag = 1;
  replace sortflag = 0 if AIMEp <= AIMEp`ranger' & AIMEp > AIMEp`mranger';
  replace sortflag2 = 1;
  replace sortflag2 = 0 if AIMEp <= AIMEp`ranger' & AIMEp > AIMEp`mranger' & AIME ~= . & matchcrit == 1;
  sort sortflag sortflag2 HHIDPN;
  while `i' <= `max2' {;
    local i2 = ceil(uniform()*`max');
    qui replace residmatch = residsmt[`i2'] in `i';
  local i = `i' + 1;
  };
local ranger = `ranger' + 10;
};

local i = 1;
qui sum AIMEp if AIMEp > AIMEp90 & AIME ~= . & matchcrit == 1;
local max = r(N);
qui sum AIMEp if AIMEp > AIMEp90;
local max2 = r(N);
replace sortflag = 1;
replace sortflag = 0 if AIMEp > AIMEp90;
replace sortflag2 = 1;
replace sortflag2 = 0 if AIMEp > AIMEp90 & AIME ~= . & matchcrit == 1;
sort sortflag sortflag2 HHIDPN;
while `i' <= `max2' {;
  local i2 = ceil(uniform()*`max');
  qui replace residmatch =  residsmt[`i2'] in `i';
  local i = `i' + 1;
};

gen AIMEpp=AIMEp+residmatch;
sum AIMEpp AIME;
replace AIME=AIMEpp if AIME==.;
replace AIME=0 if AIME<0;
replace AIME=40000 if AIME>40000; * AIME is bounded;


replace V3319=0 if V3319==.;
replace V5009=0 if V5009==.;

drop if instiew1==.;  

drop matchcrit  sortflag* resid*  Amiss;
gen penwealth=trueDBcurr+trueDCcurr+trueDBlast+trueDClast+trueDBprev+trueDCprev;
*keep HHID PN AIME medcost wage true* healw ins* age assets lfpr llfpr penD*T *miss penwealth birthyr V* pref_index lfprw1 ;
*drop instype;


save C:\HRS\SSA3\STATA\restrict4_workage, replace;

sum AIME medcost wage trueDB*;


log close ;
program drop _all ;
*drop _all ;

