# delimit ;  
* This generates the empirical joint distribution of assets, wages, health type, health insurance type;
set more 1 ; 
drop _all;
capture log close; 
set mem 500m;
set seed 53;
log using c:\research\hrs\dist\awhdist.log, replace ; 
* here I estimate the distributions of assets and wages, ages 51-55;
program drop _all;
 
use c:\research\hrs\merge\merge6;

gen FullSample=1; * 0=> 51-55 age range, 1 => 51-69 age range;

sort age;
save c:\research\hrs\merge\merge6x, replace;

* first, read in the data on medical expenses to adjust;
* the medical expense numbers to account for the fact;
* that medicaid pays much of the medical expense bill;
use c:\research\hrs\dist\meds;
drop if mu1[_n-1]~=.; * this should get rid of all but one guy;
keep mu1 mu2 mu3 mu4 mu5 age;
sum mu* age;
sort age;
* use c:\research\hrs\merge\merge6;
merge age using c:\research\hrs\merge\merge6x;
drop _merge;




sort age;
replace mu1=mu1[_n-1] if mu1==.;
replace mu2=mu2[_n-1] if mu2==.;
replace mu3=mu3[_n-1] if mu3==.;
replace mu4=mu4[_n-1] if mu4==.;
replace mu5=mu5[_n-1] if mu5==.;

gen oage=1-age;
sort oage;
replace mu1=mu1[_n-1] if mu1==.;
replace mu2=mu2[_n-1] if mu2==.;
replace mu3=mu3[_n-1] if mu3==.;
replace mu4=mu4[_n-1] if mu4==.;
replace mu5=mu5[_n-1] if mu5==.;

* generate lagged lfpr;
sort HHID PN realyear;
gen llfpr=.;
replace llfpr= lfpr[_n-1] if HHID==HHID[_n-1] & PN==PN[_n-1] & realyear<realyear[_n-1]+3;

drop if male~=1;
drop if (hrscoh~=1 & hrscoh~=12);
drop if dead==1;

tab wave;

* seems to be some problems with measuring pensions in earlier waves -- try to fill in some "0"s;
gen omwave=1-wave;
sort HHID PN omwave;
replace penDBcurr=1 if penDBcurr[_n-1]==1 & lfpr==1 & lfpr[_n-1]==1 & same[_n-1]==1;
replace penDCcurr=1 if penDCcurr[_n-1]==1 & lfpr==1 & lfpr[_n-1]==1 & same[_n-1]==1;

* place some restrictions on the range of the data for assets and wages;
replace assets=0 if assets<0 & assets~=.;
replace assets=1000000 if assets>1000000 & assets~=.;
replace vla=0 if vla<0 & vla~=.;
replace vla=500000 if vla>500000 & vla~=.;
replace wage=4 if wage<4 & lfpr==1 & wage~=.;
replace wage=60 if wage>60 & lfpr==1 & wage~=.;


* code up the health insurance data;
gen instype=.;
replace instype=1 if inspriv==1|insnone==1;
replace instype=2 if eprhi==1|inssp==1;
replace instype=3 if instie==1;
tab instype;

rename _medcost _medc;
replace _medc=0 if _medc==.;
replace _iprem=0 if _iprem==.;
replace medcost=medcost+_medc;
replace iprem=iprem+_iprem;
drop if iprem>30000 & iprem~=.;
replace medcost=250 if medcost<250;
gen lmedcost=ln(medcost);




drop if healw==.|lfprw1==.;



* many people in our data have useful lagged information;
sort indnum age;
gen impw=0;
replace impw=1 if assets==.|instype==.;


replace assets=assets[_n-1] if assets[_n-1]~=. & assets==. & indnum==indnum[_n-1] ;
replace vla=vla[_n-1] if vla[_n-1]~=. & vla==. & indnum==indnum[_n-1] ;
replace wage=wage[_n-1] if wage[_n-1]~=. & wage==. & indnum==indnum[_n-1] ;
replace healw=healw[_n-1] if healw[_n-1]~=. & healw==. & indnum==indnum[_n-1] ;
replace instype=instype[_n-1] if instype[_n-1]~=. & instype==. & indnum==indnum[_n-1] ;
*replace lfpr=lfpr[_n-1] if lfpr[_n-1]~=. & lfpr==. & indnum==indnum[_n-1] ;
replace lfprw1=lfprw1[_n-1] if lfprw1[_n-1]~=. & lfprw1==. & indnum==indnum[_n-1] ;
replace lmedcost=lmedcost[_n-1] if lmedcost[_n-1]~=. & lmedcost==. & indnum==indnum[_n-1] ;

gen omage=1-age;
sort indnum omage;

replace assets=assets[_n-1] if assets[_n-1]~=. & assets==. & indnum==indnum[_n-1] ;
replace vla=vla[_n-1] if vla[_n-1]~=. & vla==. & indnum==indnum[_n-1] ;
replace wage=wage[_n-1] if wage[_n-1]~=. & wage==. & indnum==indnum[_n-1] ;
replace healw=healw[_n-1] if healw[_n-1]~=. & healw==. & indnum==indnum[_n-1] ;
replace instype=instype[_n-1] if instype[_n-1]~=. & instype==. & indnum==indnum[_n-1] ;
*replace lfpr=lfpr[_n-1] if lfpr[_n-1]~=. & lfpr==. & indnum==indnum[_n-1] ;
replace lfprw1=lfprw1[_n-1] if lfprw1[_n-1]~=. & lfprw1==. & indnum==indnum[_n-1] ;
replace lmedcost=lmedcost[_n-1] if lmedcost[_n-1]~=. & lmedcost==. & indnum==indnum[_n-1] ;


* if current wage is missing, use wage on last job;
replace wage=wagelast if wage==.;
replace wage=earnprev/2000 if wage==.;

drop if assets==. & wage==. & healw==. & instype==. & lfpr==. & lmedcost==.;


* now generate predicted values for wages, etc;

gen wagemiss=0;
replace wagemiss=1 if wage==.;
gen medcostmiss=0;
replace medcostmiss=1 if lmedcost==.;

drop if (age<51|age>55) & FullSample==0; * age selection criteria;
drop if (age<51|age>69) & FullSample==1; * age selection criteria;
* wages first;
gen lwage =ln(wage);
sum wage lwage;
reg lwage assets healw instype lfpr ;
predict lwagep;
gen resid=(lwage-lwagep)*(lwage-lwagep);
egen var=mean(resid);
replace resid=sqrt(var);

* generate N(0,1) r.v.s;
gen rnder=invnorm(uniform());
gen lwagepp=lwagep+(rnder*resid);
sum lwagepp lwage;
replace lwage=lwagepp if lwage==.;
drop wage;
gen wage=exp(lwage);
drop rnder resid var;

* now medical expenses;

reg lmedcost  assets healw instype lfpr;
predict lmedp;
gen resid=(lmedcost-lmedp)*(lmedcost-lmedp);
egen var=mean(resid);
replace resid=sqrt(var);

* generate N(0,1) r.v.s;
gen rnder=invnorm(uniform());
gen lmedpp=lmedp+(rnder*resid);
sum lmedpp lmedcost;
replace lmedcost=lmedpp if lmedcost==.;
drop rnder resid var;

sum wave;
sum ins* epr* lmedcost* mu* assets* heal* gheal* lfpr* vla* if wave==7;


sort wave;
by wave: sum lfpr* healw instype;



drop if (instype<1 |instype>3);

sort wave;
by wave: sum lfpr* healw instype;;




replace lmedcost=lmedcost+mu1 if lfpr==1 & instype==2;
replace lmedcost=lmedcost+mu2 if lfpr==0 & instype==2;
replace lmedcost=lmedcost+mu3 if lfpr==1 & instype==3;
replace lmedcost=lmedcost+mu4 if lfpr==0 & instype==3;
replace lmedcost=lmedcost+mu5 if instype==1;
tab wave;

keep assets wage hours healw instype lmedcost *lfpr vla HHID PN medcostmiss wagemiss  wave age  impw
ind occ birthyr tenure* pen* SScov SSYears SSEnd Govt GovtYears GovtEnd faminc earn* wage* V3319* V5009* V9063*  lfprw1 eprhiw1 instiew1;

drop if assets==.|healw==.|instype==.|lfpr==.|vla==.;
drop if lmedcost==.;

saveold c:\research\hrs\dist\awhdist, replace;


drop _all;
log close;

