# delimit ; 
clear; 
set mem 300m;	
set more 1 ;  
drop _all;
program drop _all;
log using "C:\research\hrs\prof\death.log", replace; 
use "c:\research\hrs\merge\merge7a";
drop if wave>6; * wave 7 is not pulled together yet;


drop ageg* ;
gen age2=age1*age1;
gen age3=age2*age1;
gen age4=age3*age1;

* sum coding of whether people just died, as well as their previous health status;
sort indnum wave;
gen died=dead;
replace died=. if dead==1 & ((indnum==indnum[_n-1] & dead[_n-1]==1)| indnum~=indnum[_n-1] ) ;
replace died=. if dead==0 & (indnum~=indnum[_n-1] | dead[_n-1]~=0);

sort wave;
by wave: sum died age;


* recode current health status to a 2 point distribution;
replace heal=healw;
replace heal=1 if died==1;


* generate lagged health status;
sort indnum wave;
gen lheal=heal[_n-1] if indnum==indnum[_n-1];
gen lhealage=age1*lheal;
gen surv=1-died;
sort wave;


***********************GENERATE SOME PROGRAMS HERE****************;
program define genvals;
  local i = 70;
  while `i' <=100 { ;
    quietly sum _UNCOND if age == `i';
    scalar UNCONDITIONAL`i' = r(mean);
    local i = `i'+1;
  } ;
end;

program define genexpect;
  gen i = 70;
  gen i2 = 71;
  gen probUNCONDITIONAL=1;
  gen probUNCONDITIONALh=1; 
  gen cprobUNCONDITIONAL=0;

  local i = 70;
  while `i' <=100 { ;
	replace probUNCONDITIONAL=probUNCONDITIONALh*(1-UNCONDITIONAL`i');
	replace cprobUNCONDITIONAL=cprobUNCONDITIONAL+probUNCONDITIONAL;
	replace probUNCONDITIONALh=probUNCONDITIONAL;

    local i = `i' + 1;
  } ;
end;

program define predictvals;
	version 3.1;

	gen bp1=ageshift;
	gen ebp1=exp(bp1);
	gen survp1=ebp1/(1+ebp1);
	
gen _UNCONDITIONAL=1-sqrt(survp1);
drop bp1 ebp1 survp1 ; * drops intermediate output from genPIshift;
end;

**************ESTIMATION HERE ******************************;

* first, generate unconditional mortality coefficients;
logit surv age1 age2 age3  ;
gen ageshiftU=_b[_cons]+(_b[age1]*age1)+(_b[age2]*age2) +(_b[age3]*age3); 

*now, conditional on health;
logit surv age1 age2 age3  lheal lhealage ;
*logit surv age1 age2 age3 ;
gen ageshift=_b[_cons]+(_b[age1]*age1)+(_b[age2]*age2) +(_b[age3]*age3); 
gen ageshiftFINAL=ageshift; * output ageshifter;
gen healshift=_b[lheal]+_b[lhealage]*age1;
* gen healshift=0;

drop if age1<50|age1>100;

sum surv;
*rename age1 age;
sort age;
drop if age==age[_n-1];

**********************************************;
**********************************************;
predictvals;
gen healthy=_UNCOND;
genvals;
genexpect;
sum cprob*;
drop cprob* prob* i* ;
drop _*;

**********************************************;
**********************************************;
replace ageshift=ageshift+healshift; * use this to generate profiles for bad health;
predictvals;
replace ageshift=ageshift-healshift; * use this to generate profiles for bad health;
gen unhealthy=_UNCOND;
drop _*;
replace ageshift=ageshiftU;
predictvals;
gen avg=_UNCOND;

***********************************;
* GRAPHS                           ;
***********************************;

twoway connected healthy unhealthy avg age, ysc(r(0 .5)) ylabel(0(.1).5) msymbol(T S D O) lpattern(solid longdash shortdash longdash_dot) plotregion(ifcolor(pink*0.08)) ti("Probability of Death, by Previous Health Status", size(medsmall)) ytitle("") saving(death, replace);
graph use death.gph;
graph display, ysize(6) xsize(8.25);
graph export c:\research\hrs\prof\output\death.eps, replace;

genvals;
genexpect;
sum cprob*;
drop cprob* prob* i* ;
drop _*;

sort age;
by age: sum healthy unhealthy avg;






* output for DP model;
keep age healthy unhealthy avg ageshiftFINAL healshift ageshiftU ;
order age healthy unhealthy avg ageshiftFINAL healshift ageshiftU ;
outsheet using c:\research\hrs\prof\output\deathprof,nonames replace;

program drop _all;
log close;
