
# delimit ; 
clear; 
set mem 300m;	
set more 1 ;  
drop _all;
program drop _all;
log using C:\research\hrs\prof\healtrans.log, replace ; 

use c:\research\hrs\merge\merge7a;

* this program generates a       ;
* 2 year health transition matrix;


drop ageg* ;
gen age2=age1*age1;
gen age3=age2*age1;
gen age4=age3*age1;

* sum coding of whether people just died, as well as their previous health status;
sort indnum wave;
gen died=dead;
replace died=. if dead==1 & ((indnum==indnum[_n-1] & dead[_n-1]==1)| indnum~=indnum[_n-1] ) ;
replace died=. if dead==0 & (indnum~=indnum[_n-1] | dead[_n-1]~=0);

replace heal=healw;
replace heal=. if died==1|dead==1|dead==.;

* generate lagged health status;
sort indnum wave;
gen lheal=heal[_n-1] if indnum==indnum[_n-1];
gen lhealage=age1*lheal;
gen lhealage2=lhealage*age1;
sort wave;


*IMPORTANT:pg stands for gg (NOT 1-gg!!!!) and pb stands for bb;

program define genvals;
  local i = 52;
  while `i' <=100 { ;

	gen pg`i'=.;
	replace pg`i'= (1-healthy) if age==`i';
	gen pb`i'=.;
	replace pb`i'=unhealthy if age==`i';
	
    local i = `i'+1;
*sum _*;
  } ;
end;


program define ONEyear;
sum pb*;

 gen probg = 1;
 gen probb = 1;

gen A=0;
gen B=0;
gen C=0;

  local i = 52;
  while `i' <=100 { ;

	replace A=(2-pb`i' - pg`i');
	replace B=(2*pg`i'-2);
	replace C=1+(pb`i'*pb`i') - (pb`i' + pg`i' );	

	replace probb=(-B+sqrt( (B*B) - 4*(A*C) ))/(2*A) if age==`i';
	replace probg=((probb*probb)+1-probb-pb`i')/(1-probb) if age==`i';


    local i = `i' + 1;
  } ;
drop A B C;
end;

program define predictvals;
	version 3.1;
	gen bp1=ageshift;
	gen ebp1=exp(bp1);
	gen heal1=ebp1/(1+ebp1);
	drop bp1 ebp1  ; * drops intermediate output;
end;

**************ESTIMATION HERE ******************************;
logit heal age1 age2 age3 lheal lhealage; * higher order polys give wierd results at older ages;

gen ageshift=_b[_cons]+(_b[age1]*age1)+(_b[age2]*age2) +(_b[age3]*age3);
gen ageshiftFINAL=ageshift;
gen healshift=_b[lheal]+_b[lhealage]*age1;

*rename age1 age;
sort age HHID;
drop if age>100|age<50;
drop if age==age[_n-1];

********** generate predicted transitions;
predictvals;
rename heal1 healthy;

replace ageshift=ageshift+healshift;
predictvals;
replace ageshift=ageshift-healshift;
rename heal1 unhealthy;

twoway connected healthy unhealthy age, ysc(r(0 .7)) ylabel(0(.1).7) msymbol(T S D O) lpattern(solid longdash shortdash longdash_dot) plotregion(ifcolor(pink*0.08)) ti("Probability of Being in Bad Health, by Previous Health Status,", size(medsmall) span  color(black)) subtitle("health status, 2 years ago", size(medsmall) span color(black)) l1(Prob(health=bad)) ytitle("") saving(healg, replace);
graph use healg.gph;
graph display, ysize(6) xsize(8.25);
graph export  C:\research\hrs\prof\output\heal.eps, replace;

genvals;
ONEyear;
sort age1;

gen healthy1=1-probg;
gen unhealthy1=probb;
gen healthy2=healthy;
gen unhealthy2=unhealthy;
by age1:sum prob*;

replace healthy=healthy1;
replace unhealthy=unhealthy1;

twoway connected healthy unhealthy age, ysc(r(0 .8)) ylabel(0(.1).8) msymbol(T S D O) lpattern(solid longdash shortdash longdash_dot) plotregion(ifcolor(pink*0.08)) ti("Probability of Being in Bad Health, by Previous Health Status,", size(medsmall) span  color(black)) subtitle("health status 1 year ago", size(medsmall) span color(black)) l1(Prob(health=bad)) ytitle("") saving(healg1, replace);
graph use healg1.gph;
graph display, ysize(6) xsize(8.25);
graph export  C:\research\hrs\prof\output\heal1.eps, replace;



keep age1 healthy1 unhealthy1 healthy2 unhealthy2 ageshiftFINAL healshift ;
order age1 healthy1 unhealthy1 healthy2 unhealthy2 ageshiftFINAL healshift ;

outsheet using C:\research\hrs\prof\output\healthprof,nonames replace;

drop _all;
program drop _all;
log close;
